@@ -83,7 +83,10 @@ gamma_conv <- function(rawDat, ref=NA, last=NA, timeName = "time", printRanks=FA
   # select ref
   posizRef <- which(rawDat[,timeName] == ref)
   # go with the index
-  myDat <- dplyr::select(rawDat,-timeName)
+  myDat <- dplyr::select(rawDat,
+                         tidyselect::all_of(
+                            setdiff(
+                              names(rawDat),timeName)));
   myMat <- t(as.matrix(myDat))# countries by times
   myRanghi <- apply(myMat,2, function(vetto){rank(vetto)})
   if(printRanks){
